%define anolis_release 1
%bcond_without ignore_doc
%bcond_with build_optional
%bcond_with build_check

Name:           openjpeg2
Version:        2.5.2
Release:        %{anolis_release}%{?dist}
Summary:        C-Library for JPEG 2000
# windirent.h is MIT, the rest is BSD
License:        BSD and MIT
URL:            https://github.com/uclouvain/openjpeg
Source0:	https://github.com/uclouvain/openjpeg/archive/v%{version}/openjpeg-%{version}.tar.gz

%if %{with build_check}
Source1:        https://github.com/uclouvain/openjpeg-data/archive/refs/heads/master.zip
%endif

# Rename tool names to avoid conflicts with openjpeg-1.x
Patch0:         openjpeg2_opj2.patch
Patch1:         openjpeg2-2.5.2-cve-2024-56826.patch
Patch2:         openjpeg2-2.5.2-cve-2024-56827.patch

BuildRequires:  cmake gcc-c++ make
BuildRequires:  jbigkit-devel
BuildRequires:  lcms2-devel
BuildRequires:  liblerc-devel
BuildRequires:  libjpeg-turbo-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libwebp-devel
BuildRequires:  libzstd-devel
BuildRequires:  zlib-devel

%if %{without ignore_doc}
BuildRequires:  doxygen
%endif

%if %{with build_optional}
BuildRequires:  java-devel
BuildRequires:  xerces-j2
%endif

%description
The OpenJPEG library is an open-source JPEG 2000 library developed in order to
promote the use of JPEG 2000.

This package contains
* JPEG 2000 codec compliant with the Part 1 of the standard (Class-1 Profile-1
  compliance).
* JP2 (JPEG 2000 standard Part 2 - Handling of JP2 boxes and extended multiple
  component transforms for multispectral and hyperspectral imagery)


%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary:        Development files for OpenJPEG 2
Requires:       %{name} = %{version}-%{release}
# OpenJPEGTargets.cmake refers to the tools
Requires:       %{name}-tools = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for developing
applications that use OpenJPEG 2.


%package devel-docs
Summary:        Developer documentation for OpenJPEG 2
BuildArch:      noarch

%description devel-docs
The %{name}-devel-docs package contains documentation files for developing
applications that use OpenJPEG 2.


%package tools
Summary:        OpenJPEG 2 command line tools
Requires:       %{name} = %{version}-%{release}

%description tools
Command line tools for JPEG 2000 file manipulation, using OpenJPEG2:
 * opj2_compress
 * opj2_decompress
 * opj2_dump

%if %{with build_optional}
%package mj2
Summary:        OpenJPEG2 MJ2 module
Requires:       %{name} = %{version}-%{release}

%description mj2
The OpenJPEG library is an open-source JPEG 2000 library developed in order to
promote the use of JPEG 2000.

This package contains the MJ2 module (JPEG 2000 standard Part 3)


%package mj2-devel
Summary:        Development files for OpenJPEG2 MJ2 module
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-mj2 = %{version}-%{release}

%description mj2-devel
Development files for OpenJPEG2 MJ2 module


%package mj2-tools
Summary:        OpenJPEG2 MJ2 module command line tools
Requires:       %{name}-mj2 = %{version}-%{release}

%description mj2-tools
OpenJPEG2 MJ2 module command line tools

%package jpwl
Summary:        OpenJPEG2 JPWL module
Requires:       %{name} = %{version}-%{release}

%description jpwl
The OpenJPEG library is an open-source JPEG 2000 library developed in order to
promote the use of JPEG 2000.

This package contains the JPWL (JPEG 2000 standard Part 11 - Jpeg 2000 Wireless)


%package jpwl-devel
Summary:        Development files for OpenJPEG2 JPWL module
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-jpwl = %{version}-%{release}

%description jpwl-devel
Development files for OpenJPEG2 JPWL module


%package jpwl-tools
Summary:        OpenJPEG2 JPWL module command line tools
Requires:       %{name}-jpwl = %{version}-%{release}

%description jpwl-tools
OpenJPEG2 JPWL module command line tools

%package jpip
Summary:        OpenJPEG2 JPIP module
Requires:       %{name} = %{version}-%{release}

%description jpip
The OpenJPEG library is an open-source JPEG 2000 library developed in order to
promote the use of JPEG 2000.

This package contains the JPWL (JPEG 2000 standard Part 9 - Jpeg 2000 Interactive Protocol)


%package jpip-devel
Summary:        Development files for OpenJPEG2 JPIP module
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-jpwl = %{version}-%{release}

%description jpip-devel
Development files for OpenJPEG2 JPIP module


%package jpip-tools
Summary:        OpenJPEG2 JPIP module command line tools
Requires:       %{name}-jpip = %{version}-%{release}
Requires:       jpackage-utils
Requires:       java

%description jpip-tools
OpenJPEG2 JPIP module command line tools

%package jp3d
Summary:        OpenJPEG2 JP3D module
Requires:       %{name} = %{version}-%{release}

%description jp3d
The OpenJPEG library is an open-source JPEG 2000 library developed in order to
promote the use of JPEG 2000.

This package contains the JP3D (JPEG 2000 standard Part 10 - Jpeg 2000 3D)


%package jp3d-devel
Summary:        Development files for OpenJPEG2 JP3D module
Requires:       %{name}-devel = %{version}-%{release}
Requires:       %{name}-jp3d = %{version}-%{release}

%description jp3d-devel
Development files for OpenJPEG2 JP3D module


%package jp3d-tools
Summary:        OpenJPEG2 JP3D module command line tools
Requires:       %{name}-jp3d = %{version}-%{release}

%description jp3d-tools
OpenJPEG2 JP3D module command line tools
%endif

%prep
%autosetup -p1 -n openjpeg-%{version}
%if %{with build_check}
%autosetup -p1 -a 1
%endif

%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DOPENJPEG_INSTALL_LIB_DIR=%{_lib} \
%if %{with build_optional}
    -DBUILD_MJ2=ON -DBUILD_JPWL=ON -DBUILD_JPIP=ON -DBUILD_JP3D=ON \
%endif
%if %{without ignore_doc}
    -DBUILD_DOC=ON \
%else
    -DBUILD_DOC=OFF \
%endif
%if %{with build_check}
    -DBUILD_TESTING:BOOL=ON -DOPJ_DATA_ROOT=$PWD/../data \
%endif
    -DBUILD_STATIC_LIBS=OFF \
    -DBUILD_SHARED_LIBS=ON \
    %{?runcheck:-DBUILD_TESTING:BOOL=ON -DOPJ_DATA_ROOT=$PWD/../data}
%cmake_build

%install
%cmake_install

%if %{without ignore_doc}
mv %{buildroot}%{_mandir}/man1/opj_compress.1 %{buildroot}%{_mandir}/man1/opj2_compress.1
mv %{buildroot}%{_mandir}/man1/opj_decompress.1 %{buildroot}%{_mandir}/man1/opj2_decompress.1
mv %{buildroot}%{_mandir}/man1/opj_dump.1 %{buildroot}%{_mandir}/man1/opj2_dump.1

rm -rf %{buildroot}%{_datadir}/doc/
%endif

%if %{with build_optional}
# Move the jar to the correct place
mkdir -p %{buildroot}%{_javadir}
mv %{buildroot}%{_datadir}/opj_jpip_viewer.jar %{buildroot}%{_javadir}/opj2_jpip_viewer.jar
cat > %{buildroot}%{_bindir}/opj2_jpip_viewer <<EOF
java -jar %{_javadir}/opj2_jpip_viewer.jar "$@"
EOF
chmod +x %{buildroot}%{_bindir}/opj2_jpip_viewer
%endif

%check
%if %{with build_check}
%ctest
%endif

%files
%license LICENSE
%{_libdir}/libopenjp2.so.*
%if %{without ignore_doc}
%{_mandir}/man3/libopenjp2.3*
%endif

%files devel
%dir %{_includedir}/openjpeg-2.5/
%{_includedir}/openjpeg-2.5/openjpeg.h
%{_includedir}/openjpeg-2.5/opj_config.h
%{_libdir}/libopenjp2.so
%{_libdir}/cmake/openjpeg-2.5/
%{_libdir}/pkgconfig/libopenjp2.pc

%if %{without ignore_doc}
%files devel-docs
%doc %{__cmake_builddir}/doc/html
%endif

%files tools
%{_bindir}/opj2_compress
%{_bindir}/opj2_decompress
%{_bindir}/opj2_dump
%if %{without ignore_doc}
%{_mandir}/man1/opj2_compress.1*
%{_mandir}/man1/opj2_decompress.1*
%{_mandir}/man1/opj2_dump.1*
%endif
%if %{with build_optional}
%files mj2
%{_libdir}/libopenmj2.so.*

%files mj2-devel
%{_libdir}/libopenmj2.so

%files mj2-tools
%{_bindir}/opj2_mj2*

%files jpwl
%{_libdir}/libopenjpwl.so.*

%files jpwl-devel
%{_libdir}/libopenjpwl.so
%{_libdir}/pkgconfig/libopenjpwl.pc

%files jpwl-tools
%{_bindir}/opj2_jpwl*

%files jpip
%{_libdir}/libopenjpip.so.*

%files jpip-devel
%{_libdir}/libopenjpip.so
%{_libdir}/pkgconfig/libopenjpip.pc

%files jpip-tools
%{_bindir}/opj2_jpip*
%{_bindir}/opj2_dec_server
%{_javadir}/opj2_jpip_viewer.jar

%files jp3d
%{_libdir}/libopenjp3d.so.*

%files jp3d-devel
%{_includedir}/openjpeg-2.0/openjp3d.h
%{_libdir}/libopenjp3d.so
%{_libdir}/pkgconfig/libopenjp3d.pc

%files jp3d-tools
%{_bindir}/opj2_jp3d*
%endif

%files doc
%doc AUTHORS.md NEWS.md README.md THANKS.md

%changelog
* Wed Mar 19 2025 Hong Wei Qin <qhw01063182@alibaba-inc.com> - 2.5.2-1
- Update to 2.5.0 from 2.5.2
- Remove patches because bugs are not exist in new version.
- Add patches to fix CVE-2024-56826 and CVE-2024-52827
- [Patches cherry-picked from c10s. Original changelog:
  - Fix precedence of casts. (2.5.2-4)]
- Add patchs to fix build failed

* Mon Apr 10 2023 Kun(llfl) <llfl@linux.alibaba.com> -  2.5.0-5
- optimize spec file

* Fri Mar 10 2023 Funda Wang <fundawang@yeah.net> - 2.5.0-4
- Drop mingw support

* Sat Jan 21 2023 Funda Wang <fundawang@yeah.net> - 2.5.0-3
- Enable doc build

* Thu Jan 19 2023 Funda Wang <fundawang@yeah.net> - 2.5.0-2
- Rebuild for new libtiff
- Disable circular dependencies between openjpeg and ghostscript for now

* Thu Sep 22 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.5.0-1
- update to 2.5.0

* Tue Apr 19 2022 zhang xianting <zhangxianting@uniontech.com> - 2.4.0-1
- Initial build for Anolis V23
